.. _install:

Instalación de CURP Suite
=========================

El primer paso para usar CURP Suite es instalarlo.


$ python3 -m pip install curpsuite
----------------------------------

Para instalar CURP Suite, simplemente usa este comando en la terminal::

    $ python3 -m pip install curpsuite

CURP Suite es compatible con Python 3.8 en adelante.


Obtener el Código Fuente
------------------------

CURP Suite reside en GitHub.
Si deseas conseguir una copia del código fuente, clona el repositorio público.

::

    $ git clone https://github.com/jacobszpz/CURPSuite.git

Para instalar las dependencias::

    $ cd CURPSuite
    $ pipenv install --dev
